@@ -301,6 +301,10 @@ our %servers = qw(
     BERLIN          whois.nic.berlin
     KIWI            whois.dot-kiwi.com
     BUILD           whois.nic.build
+    CLUB            whois.nic.club
+    LUXURY          whois.nic.luxury
+    WIEN            whois.nic.wien
+    ONE             whois.nic.one
 
     PINK            whois.afilias.net
     RED             whois.afilias.net
@@ -308,10 +312,6 @@ our %servers = qw(
     KIM             whois.afilias.net
     BLUE            whois.afilias.net
 
-    CLUB            whois.nic.club
-    LUXURY          whois.nic.luxury
-    WIEN            whois.nic.wien
-
     ACTOR           whois.unitedtld.com
     AIRFORCE        whois.unitedtld.com
     ARMY            whois.unitedtld.com
@@ -664,6 +664,11 @@ our %servers = qw(
     ORG.UK      whois.nic.uk
     PLC.UK      whois.nic.uk
 
+    CO.ZA       whois.co.za
+    NET.ZA      whois.net.za
+    ORG.ZA      whois.org.za
+    WEB.ZA      whois.web.za
+
     XN--P1AG    ru.whois.i-dns.net
     XN--P1AG    ru.whois.i-dns.net
     XN--J1AEF   whois.i-dns.net
@@ -703,6 +708,7 @@ our %servers = qw(
     XXX         whois.nic.xxx
     MOSCOW      whois.nic.moscow
     TATAR       whois.nic.tatar
+    PRESS       whois.nic.press
 );
 
 
@@ -949,11 +955,11 @@ our %notfound = (
     'whois.ttpia.com'           => 'No match for',
     'whois.worldnames.net'      => 'NO MATCH for domain',
      # 'whois.yournamemonkey.com' -- need try again
-    'whois.cnnic.net.cn'	=> 'no matching record',
+    'whois.cnnic.net.cn'        => 'no matching record',
     'whois.nic.co'              => 'Not found: \S+',
-    'me.whois-servers.net'	=> 'NOT FOUND',
+    'me.whois-servers.net'      => 'NOT FOUND',
     'whois.domain.kg'           => 'Data not found. This domain is available for registration.',
-    'whois.nic.so'              => 'Not\s+found:',
+    'whois.nic.one'             => 'No Data Found',
 
     # for VN | TJ zones
     'www_whois'                 => '(Available|no records found|is free|Not Registered)',
@@ -965,6 +971,7 @@ our %notfound = (
     'whois.nic.xn--80adxhks'      => 'No entries found for the selected source',
     'whois.nic.moscow'            => 'No entries found for the selected source',
     'whois.nic.tatar'             => 'No entries found for the selected source',
+    'whois.nic.press'             => 'DOMAIN NOT FOUND',
 );
 
 # Common whois stripping REs
